@@ -375,6 +375,9 @@ void MainWidget::configure()
     dlg->addModule(QStringLiteral("akonadicontact_actions.desktop"));
     dlg->addModule(QStringLiteral("kcmldap.desktop"));
     dlg->addModule(QStringLiteral("kaddressbook_config_plugins.desktop"));
+#ifdef WITH_KUSERFEEDBACK
+    dlg->addModule(QStringLiteral("kaddressbook_config_userfeedback.desktop"));
+#endif
 
     dlg->exec();
     delete dlg;
@@ -387,7 +390,8 @@ void MainWidget::handleCommandLine(const QStringList &arguments)
     parser.process(arguments);
 
     if (parser.isSet(QStringLiteral("import"))) {
-        for (const QString &urlStr : parser.positionalArguments()) {
+        const QStringList lst = parser.positionalArguments();
+        for (const QString &urlStr : lst) {
             const QUrl url(QUrl::fromUserInput(urlStr));
             for (KAddressBookImportExport::KAddressBookImportExportPluginInterface *interface : qAsConst(mImportExportPluginInterfaceList)) {
                 if (interface->canImportFileType(url)) {
@@ -739,7 +743,7 @@ void MainWidget::print()
 
     QPointer<QPrintDialog> printDialog = new QPrintDialog(&printer, this);
 
-    printDialog->setWindowTitle(i18n("Print Contacts"));
+    printDialog->setWindowTitle(i18nc("@title:window", "Print Contacts"));
     if (!printDialog->exec() || !printDialog) {
         delete printDialog;
         return;
