@@ -3,7 +3,7 @@
   Copyright (c) 1996-2002 Mirko Boehm <mirko@kde.org>
                           Tobias Koenig <tokoe@kde.org>
 
-  Copyright (c) 2009-2019 Laurent Montel <montel@kde.org>
+  Copyright (c) 2009-2020 Laurent Montel <montel@kde.org>
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
@@ -56,7 +56,7 @@ PrintingWizard::PrintingWizard(QPrinter *printer, QItemSelectionModel *selection
     , mPrinter(printer)
     , mStyle(nullptr)
 {
-    setWindowTitle(i18n("Print Contacts"));
+    setWindowTitle(i18nc("@title:window", "Print Contacts"));
 
     mSelectionPage = new KAddressBookImportExport::KAddressBookContactSelectionWidget(selectionModel, this);
     mSelectionPage->setMessageText(i18n("Which contacts do you want to print?"));
